#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conversion-text
version:              1.0.1.1
visibility:           public
id:                   conversion-text-1.0.1.1-BgA2plHLZmBLuDxV7xlwfT
key:                  conversion-text-1.0.1.1-BgA2plHLZmBLuDxV7xlwfT
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/conversion-text 
synopsis:             "Conversion" instances for the "text" library 
category:             Control, Data, Conversion
abi:                  7095800e6a0a57a64da009be937f4395
exposed:              True
exposed-modules:      Conversion.Text
import-dirs:          /usr/lib/ghc-9.6.6/site-local/conversion-text-1.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conversion-text-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conversion-text-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conversion-text
hs-libraries:         HSconversion-text-1.0.1.1-BgA2plHLZmBLuDxV7xlwfT
depends:
    base-prelude-1.6.1.1-D2kQqMusnHdEzaJTSBYmnI bytestring-0.11.5.3
    conversion-1.2.1-7Xr9OByyNtqGgcV4uaLSoJ
    conversion-bytestring-1.0.1.1-1XYXkDeOhLq9UjjP0Gas1E text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-conversion-text/html/conversion-text.haddock

haddock-html:         /usr/share/doc/haskell-conversion-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

